pub struct GetResponse {
pub metadata: Metadata,
pub stream: ClientStream,
}Expand description
The result from a successful get() call.
This carries the response as a stream, plus the compression algorithm of the data.
Fields
metadata: MetadataThe metadata attached to this object, including the compression algorithm used for the payload.
stream: ClientStreamThe response stream.
Implementations