pub struct SecretKey {
pub kid: String,
pub secret_key: String,
}Expand description
Key configuration that will be used to sign tokens in Objectstore requests.
Fields
kid: StringA key ID that Objectstore must use to load the corresponding public key.
secret_key: StringAn EdDSA private key.