Session

Struct Session 

pub struct Session { /* private fields */ }
Represents a session with Objectstore, tied to a specific Usecase and Scope within it.

Create a Session using Client::session or Scope::session.

Implementations

Source

impl Session

pub fn object_url(&self, object_key: &str) -> Url

Generates a GET url to the object with the given key.

This can then be used by downstream services to fetch the given object. NOTE however that the service does not strictly follow HTTP semantics, in particular in relation to Accept-Encoding.

pub fn mint_token(&self) -> Result<Option<String>>

Returns a signed token if a token or generator was provided or None otherwise

Source

impl Session

pub fn delete(&self, key: &str) -> DeleteBuilder

Deletes the object with the given key.

Source

impl Session

pub fn get(&self, key: &str) -> GetBuilder

Retrieves the object with the given key.

Source

impl Session

pub fn head(&self, key: &str) -> HeadBuilder

Checks whether an object exists and retrieves its metadata.

If the object exists and has a TTI expiration policy, this is considered an access, and therefore bumps its expiration.

Source

impl Session

pub fn many(&self) -> ManyBuilder

Creates a ManyBuilder associated with this session.

A ManyBuilder can be used to enqueue multiple operations, which the client can choose to send as batch requests via a dedicated endpoint, minimizing network overhead.

Source

impl Session

pub fn initiate_multipart_upload(&self) -> InitiateMultipartBuilder

Creates a builder for initiating a multipart upload.

The returned InitiateMultipartBuilder inherits the session’s default compression and expiration settings.

IMPORTANT: unlike single-object uploads, the client does not automatically compress the contents of MultipartUpload::put/MultipartUpload::put_stream based on the configured compression. The caller is responsible to compress the payload in accordance with the configured compression. That’s because we require content_length on each part to be the length of the compressed content, which we wouldn’t be able to know beforehand if objectstore_client automatically compressed payloads on the fly.

pub fn resume_multipart_upload( &self, key: impl Into<ObjectKey>, upload_id: impl Into<String>, ) -> Result<MultipartUpload>

Resumes an existing multipart upload from its key and upload ID.

This reconstructs a MultipartUpload handle from previously obtained identifiers, and doesn’t make any network calls. Use this to resume an upload after a process restart or to continue an upload initiated elsewhere.

Source

impl Session

pub fn put(&self, body: impl Into<Bytes>) -> PutBuilder

Creates or replaces an object using a [Bytes]-like payload.

pub fn put_stream(&self, body: ClientStream) -> PutBuilder

Creates or replaces an object using a streaming payload.

pub fn put_read<R>(&self, body: R) -> PutBuilder
where R: AsyncRead + Send + Sync + 'static,

Creates or replaces an object using an [AsyncRead] payload.

pub fn put_file(&self, file: File) -> PutBuilder

Creates or replaces an object using the contents of an opened file.

The file descriptor is held open from the moment this method is called until the upload completes. When enqueueing many files via Session::many, prefer put_path instead: it defers opening the file until just before upload, keeping file descriptor usage within the active concurrency window and avoiding OS file descriptor limit (e.g., macOS’s default ulimit -n) exhaustion.

pub fn put_path(&self, path: impl Into<PathBuf>) -> PutBuilder

Creates or replaces an object using the contents of the file at path.

Unlike put_file, this method defers opening the file until the request is actually sent. When enqueueing many file uploads via Session::many, this ensures that file descriptors are opened only within the active concurrency window, preventing the process from exhausting the OS file descriptor limit (e.g., macOS’s default ulimit -n).

Prefer put_path over put_file whenever you are lining up a large number of files for upload.