pub struct TokenRequest<'a> { /* private fields */ }Expand description
A request to mint a new token returned from TokenGenerator::create_token.
Implementations
Sourceimpl TokenRequest<'_>
impl TokenRequest<'_>
Sourcepub fn permissions(self, permissions: &[Permission]) -> Self
pub fn permissions(self, permissions: &[Permission]) -> Self
Override the permissions for this token, which must be a subset of the generator’s permissions.
Sourcepub fn expiry_seconds(self, expiry_seconds: u64) -> Self
pub fn expiry_seconds(self, expiry_seconds: u64) -> Self
Set the expiry duration for this token, overriding the generator’s default.