pub enum Error {
Show 14 variants
Reqwest(Error),
Io(Error),
Utf8(FromUtf8Error),
Metadata(Error),
InvalidScope(InvalidScopeError),
TokenError(Error),
InvalidUrl {
message: String,
},
Multipart(Error),
MalformedResponse(String),
Batch(Arc<Error>),
OperationFailure {
status: u16,
message: String,
},
InvalidPartNumber(u32),
InvalidUploadId(InvalidUploadId),
MultipartComplete {
code: String,
message: String,
},
}Expand description
Errors that can happen within the objectstore-client
Variants
Reqwest(Error)
Any error emitted from the underlying [reqwest] client.
Io(Error)
IO errors related to payload streaming.
Utf8(FromUtf8Error)
Errors related to UTF-8 dcoding
Metadata(Error)
Errors handling metadata, such as serializing it to/from HTTP headers.
InvalidScope(InvalidScopeError)
Error when scope validation fails.
TokenError(Error)
Error when creating auth tokens, such as invalid keys.
InvalidUrl
Error when URL manipulation fails.
Multipart(Error)
Error when parsing a multipart response.
MalformedResponse(String)
Error when the server returned a malformed response.
Batch(Arc<Error>)
Error that indicates that an entire batch request failed.
OperationFailure
Error that indicates failure of an individual operation in a batch request.
Fields
InvalidPartNumber(u32)
Error when part number validation fails (must be >= 1).
InvalidUploadId(InvalidUploadId)
Error when upload ID validation fails.
MultipartComplete
Error returned when attempting to complete a multipart upload.