pub enum OperationResult {
Get(ObjectKey, Result<Option<GetResponse>, Error>),
Put(ObjectKey, Result<PutResponse, Error>),
Delete(ObjectKey, Result<DeleteResponse, Error>),
Error(Error),
}Expand description
The result of an individual operation.
Variants
Get(ObjectKey, Result<Option<GetResponse>, Error>)
The result of a get operation.
Returns Ok(None) if the object was not found.
Put(ObjectKey, Result<PutResponse, Error>)
The result of a put operation.
Delete(ObjectKey, Result<DeleteResponse, Error>)
The result of a delete operation.
Error(Error)
An error occurred while parsing or correlating a response part.
This makes it impossible to attribute the error to a specific operation. It can happen if the response contains malformed or missing headers, references unknown operation indices, or if a network error occurs while reading a response part.