ManyBuilder

Struct ManyBuilder 

pub struct ManyBuilder { /* private fields */ }
A builder that can be used to enqueue multiple operations.

The client can optionally execute the operations as batch requests, leading to reduced network overhead.

Implementations

Source

impl ManyBuilder

pub fn send(self) -> OperationResults

Consumes this builder, returning a lazy stream over all the enqueued operations’ results.

The results are not guaranteed to be in the order they were originally enqueued in.

pub fn push<B: Into<BatchOperation>>(self, builder: B) -> Self

Enqueues an operation.

This method takes a GetBuilder/PutBuilder/DeleteBuilder, which you can construct using Session::get/Session::put/Session::delete.

Important: All pushed builders must originate from the same Session that was used to create this ManyBuilder. Mixing builders from different sessions is not supported and will result in all operations being executed against this ManyBuilder’s session, silently ignoring the original builder’s session.