pub struct MultipartUpload { /* private fields */ }Expand description
Represents an ongoing Multipart Upload, tied to a specific Session and UploadId.
Create a Multipart Upload handle using Session::initiate_multipart_upload or Session::resume_multipart_upload.
Implementations
Sourceimpl MultipartUpload
impl MultipartUpload
Sourcepub async fn put(
&self,
body: impl Into<Bytes>,
part_number: u32,
content_md5: Option<&[u8; 16]>,
) -> Result<CompletePart>
pub async fn put( &self, body: impl Into<Bytes>, part_number: u32, content_md5: Option<&[u8; 16]>, ) -> Result<CompletePart>
Uploads a part using a [Bytes]-like payload.
IMPORTANT: unlike single-object uploads, the client does not automatically compress
contents based on this upload’s Metadata::compression.
The caller is responsible to compress the payload in accordance with the compression,
and, optionally, to pass the content_md5 of the compressed payload.
Sourcepub async fn put_stream(
&self,
stream: ClientStream,
part_number: u32,
content_length: u64,
content_md5: Option<&[u8; 16]>,
) -> Result<CompletePart>
pub async fn put_stream( &self, stream: ClientStream, part_number: u32, content_length: u64, content_md5: Option<&[u8; 16]>, ) -> Result<CompletePart>
Uploads a part using a streaming payload.
IMPORTANT: unlike single-object uploads, the client does not automatically compress
contents based on this upload’s Metadata::compression.
The caller is responsible to compress the payload in accordance with the compression,
and to pass the content_length and, optionally, content_md5 of the compressed payload.
Sourcepub async fn put_read<R>(
&self,
reader: R,
part_number: u32,
content_length: u64,
content_md5: Option<&[u8; 16]>,
) -> Result<CompletePart>
pub async fn put_read<R>( &self, reader: R, part_number: u32, content_length: u64, content_md5: Option<&[u8; 16]>, ) -> Result<CompletePart>
Uploads a part from an [AsyncRead] source.
IMPORTANT: unlike single-object uploads, the client does not automatically compress
contents based on this upload’s Metadata::compression.
The caller is responsible to compress the payload in accordance with the compression,
and to pass the content_length and, optionally, content_md5 of the compressed payload.
Sourcepub async fn list_parts(&self) -> Result<Vec<PartInfo>>
pub async fn list_parts(&self) -> Result<Vec<PartInfo>>
Lists all parts that have been uploaded for this multipart upload.
Sourcepub async fn complete(
self,
parts: impl IntoIterator<Item = CompletePart>,
) -> Result<ObjectKey>
pub async fn complete( self, parts: impl IntoIterator<Item = CompletePart>, ) -> Result<ObjectKey>
Completes the multipart upload, assembling all parts into the final object.