pub struct PutBuilder { /* private fields */ }Expand description
A PUT request builder.
Implementations
Sourceimpl PutBuilder
impl PutBuilder
Sourcepub fn key(self, key: impl Into<String>) -> Self
pub fn key(self, key: impl Into<String>) -> Self
Sets an explicit object key.
If a key is specified, the object will be stored under that key. Otherwise, the objectstore server will automatically assign a random key, which is then returned from this request.
Sourcepub fn compression(self, compression: impl Into<Option<Compression>>) -> Self
pub fn compression(self, compression: impl Into<Option<Compression>>) -> Self
Sets an explicit compression algorithm to be used for this payload.
None should be used if no compression should be performed by the client,
either because the payload is uncompressible (such as a media format), or if the user
will handle any kind of compression, without the clients knowledge.
Sourcepub fn expiration_policy(self, expiration_policy: ExpirationPolicy) -> Self
pub fn expiration_policy(self, expiration_policy: ExpirationPolicy) -> Self
Sets the expiration policy of the object to be uploaded.
Sourcepub fn content_type(self, content_type: impl Into<Cow<'static, str>>) -> Self
pub fn content_type(self, content_type: impl Into<Cow<'static, str>>) -> Self
Sets the content type of the object to be uploaded.
Sourceimpl PutBuilder
impl PutBuilder
Sourcepub async fn send(self) -> Result<PutResponse>
pub async fn send(self) -> Result<PutResponse>
Sends the built PUT request to the upstream service.