PutBuilder

Struct PutBuilder 

pub struct PutBuilder<'a> { /* private fields */ }
A PUT request builder.

Implementations

Source

impl PutBuilder<'_>

pub fn compression(self, compression: impl Into<Option<Compression>>) -> Self

Sets an explicit compression algorithm to be used for this payload.

None should be used if no compression should be performed by the client, either because the payload is uncompressible (such as a media format), or if the user will handle any kind of compression, without the clients knowledge.

pub fn expiration_policy(self, expiration_policy: ExpirationPolicy) -> Self

Sets the expiration policy of the object to be uploaded.

pub fn set_metadata(self, metadata: impl Into<BTreeMap<String, String>>) -> Self

This sets the custom metadata to the provided map.

It will clear any previously set metadata.

pub fn append_metadata( self, key: impl Into<String>, value: impl Into<String>, ) -> Self

Appends they key/value to the custom metadata of this object.

Source

impl PutBuilder<'_>

pub async fn send(self) -> Result<PutResponse>

Sends the built PUT request to the upstream service.