pub struct PutBuilder { /* private fields */ }Expand description
A put request builder.
Implementations
Sourceimpl PutBuilder
impl PutBuilder
Sourcepub fn key(self, key: impl Into<ObjectKey>) -> Self
pub fn key(self, key: impl Into<ObjectKey>) -> Self
Sets an explicit object key.
If a key is specified, the object will be stored under that key. Otherwise, the Objectstore server will automatically assign a random key, which is then returned from this request.
Sourcepub fn compression(self, compression: impl Into<Option<Compression>>) -> Self
pub fn compression(self, compression: impl Into<Option<Compression>>) -> Self
Sets an explicit compression algorithm to be used for this payload.
None should be used if no compression should be performed by the client,
either because the payload is uncompressible (such as a media format), or if the user
will handle any kind of compression, without the clients knowledge.
By default, the compression algorithm set on this Session’s Usecase is used.
Sourcepub fn expiration_policy(self, expiration_policy: ExpirationPolicy) -> Self
pub fn expiration_policy(self, expiration_policy: ExpirationPolicy) -> Self
Sets the expiration policy of the object to be uploaded.
By default, the expiration policy set on this Session’s Usecase is used.
Sourcepub fn content_type(self, content_type: impl Into<Cow<'static, str>>) -> Self
pub fn content_type(self, content_type: impl Into<Cow<'static, str>>) -> Self
Sets the content type of the object to be uploaded.
You can use the utility function crate::utils::guess_mime_type to attempt to guess a
content_type based on magic bytes.
Sourcepub fn origin(self, origin: impl Into<String>) -> Self
pub fn origin(self, origin: impl Into<String>) -> Self
Sets the origin of the object, typically the IP address of the original source.
This is an optional but encouraged field that tracks where the payload was originally obtained from. For example, the IP address of the Sentry SDK or CLI that uploaded the data.
Example
session.put("data")
.origin("203.0.113.42")
.send()
.await
.unwrap();Sourceimpl PutBuilder
impl PutBuilder
Sourcepub async fn send(self) -> Result<PutResponse>
pub async fn send(self) -> Result<PutResponse>
Sends the built put request to the upstream service.