pub struct ResumableUpload { /* private fields */ }Expand description
A handle bound to one resumable upload session.
See the crate-level documentation for more information and examples on using this API.
Implementations
Sourceimpl ResumableUpload
impl ResumableUpload
Sourcepub fn token(&self) -> &SessionToken
pub fn token(&self) -> &SessionToken
Returns the session token bound to this upload.
Sourcepub fn progress(&self) -> UploadProgressBuilder
pub fn progress(&self) -> UploadProgressBuilder
Builds a request for the server’s authoritative upload progress.
Sourcepub fn put(&self, offset: u64, chunk: impl Into<Bytes>) -> PutChunkBuilder
pub fn put(&self, offset: u64, chunk: impl Into<Bytes>) -> PutChunkBuilder
Builds a request to write chunk starting at offset.
put doesn’t perform any automatic compression of the payload, so the caller is
responsible for applying compression to the entire payload beforehand and passing chunks
of the already compressed payload to this method.
The returned progress contains the authoritative server offset, which should be used for subsequent requests.
Sourcepub fn cancel(&self) -> CancelUploadBuilder
pub fn cancel(&self) -> CancelUploadBuilder
Builds a request to cancel this upload session, discarding any uploaded bytes.