pub struct Usecase { /* private fields */ }Expand description
An identifier for a workload in Objectstore, along with defaults to use for all operations within that Usecase.
Usecases need to be statically defined in Objectstore’s configuration server-side. Objectstore can make decisions based on the Usecase. For example, choosing the most suitable storage backend.
Implementations
Sourceimpl Usecase
impl Usecase
Sourcepub fn compression(&self) -> Compression
pub fn compression(&self) -> Compression
TODO: document
Sourcepub fn with_compression(self, compression: Compression) -> Self
pub fn with_compression(self, compression: Compression) -> Self
TODO: document
Sourcepub fn expiration(&self) -> ExpirationPolicy
pub fn expiration(&self) -> ExpirationPolicy
TODO: document
Sourcepub fn with_expiration(self, expiration: ExpirationPolicy) -> Self
pub fn with_expiration(self, expiration: ExpirationPolicy) -> Self
TODO: document
Sourcepub fn for_organization(&self, organization: u64) -> Scope
pub fn for_organization(&self, organization: u64) -> Scope
TODO: document
Sourcepub fn for_project(&self, organization: u64, project: u64) -> Scope
pub fn for_project(&self, organization: u64, project: u64) -> Scope
TODO: document